@@ -24,7 +24,7 @@ from __future__ import annotations
 
 import ast
 from inspect import Parameter as SignatureParameter
-from inspect import Signature, cleandoc
+from inspect import Signature, cleandoc, getsourcelines
 from inspect import signature as getsignature
 from typing import TYPE_CHECKING, Any, Sequence
 
@@ -35,6 +35,7 @@ from griffe.enumerations import ObjectKind, ParameterKind
 from griffe.expressions import safe_get_annotation
 from griffe.extensions.base import Extensions, load_extensions
 from griffe.importer import dynamic_import
+from griffe.logger import get_logger
 
 if TYPE_CHECKING:
     from pathlib import Path
@@ -43,6 +44,7 @@ if TYPE_CHECKING:
     from griffe.expressions import Expr
 
 
+logger = get_logger(__name__)
 empty = Signature.empty
 
 
@@ -148,6 +150,16 @@ class Inspector:
             parser_options=self.docstring_options,
         )
 
+    def _get_linenos(self, node: ObjectNode) -> tuple[int, int] | tuple[None, None]:
+        # Line numbers won't be useful if we don't have the source code.
+        if not self.filepath or self.filepath not in self.lines_collection:
+            return None, None
+        try:
+            lines, lineno = getsourcelines(node.obj)
+        except (OSError, TypeError):
+            return None, None
+        return lineno, lineno + "".join(lines).rstrip().count("\n")
+
     def get_module(self, import_paths: Sequence[str | Path] | None = None) -> Module:
         """Build and return the object representing the module attached to this inspector.
 
@@ -176,6 +188,9 @@ class Inspector:
             parent_path = self.filepath.parent
             for _ in range(import_path.count(".")):
                 parent_path = parent_path.parent
+            # Climb up one more time for `__init__` modules.
+            if self.filepath.stem == "__init__":
+                parent_path = parent_path.parent
             if parent_path not in import_paths:
                 import_paths.insert(0, parent_path)
 
@@ -215,9 +230,34 @@ class Inspector:
             before_inspector.inspect(node)
 
         for child in node.children:
-            target_path = child.alias_target_path
-            if target_path:
-                self.current.set_member(child.name, Alias(child.name, target_path))
+            if target_path := child.alias_target_path:
+                # If the child is an actual submodule of the current module,
+                # and has no `__file__` set, we won't find it on the disk so we must inspect it now.
+                # For that we instantiate a new inspector and use it to inspect the submodule,
+                # then assign the submodule as member of the current module.
+                # If the submodule has a `__file__` set, the loader should find it on the disk,
+                # so we skip it here (no member, no alias, just skip it).
+                if child.is_module and target_path == f"{self.current.path}.{child.name}":
+                    if not hasattr(child.obj, "__file__"):
+                        logger.debug(f"Module {target_path} is not discoverable on disk, inspecting right now")
+                        inspector = Inspector(
+                            child.name,
+                            filepath=None,
+                            parent=self.current.module,
+                            extensions=self.extensions,
+                            docstring_parser=self.docstring_parser,
+                            docstring_options=self.docstring_options,
+                            lines_collection=self.lines_collection,
+                            modules_collection=self.modules_collection,
+                        )
+                        try:
+                            inspector.inspect_module(child)
+                        finally:
+                            self.extensions.attach_inspector(self)
+                        self.current.set_member(child.name, inspector.current.module)
+                # Otherwise, alias the object.
+                else:
+                    self.current.set_member(child.name, Alias(child.name, target_path))
             else:
                 self.inspect(child)
 
@@ -261,10 +301,13 @@ class Inspector:
                 continue
             bases.append(f"{base.__module__}.{base.__qualname__}")
 
+        lineno, endlineno = self._get_linenos(node)
         class_ = Class(
             name=node.name,
             docstring=self._get_docstring(node),
             bases=bases,
+            lineno=lineno,
+            endlineno=endlineno,
         )
         self.current.set_member(node.name, class_)
         self.current = class_
@@ -345,7 +388,6 @@ class Inspector:
         Parameters:
             node: The node to inspect.
         """
-        node.obj = node.obj.func
         self.handle_function(node, {"cached", "property"})
 
     def inspect_property(self, node: ObjectNode) -> None:
@@ -384,6 +426,8 @@ class Inspector:
                 else _convert_object_to_annotation(return_annotation, parent=self.current)
             )
 
+        lineno, endlineno = self._get_linenos(node)
+
         obj: Attribute | Function
         labels = labels or set()
         if "property" in labels:
@@ -392,6 +436,8 @@ class Inspector:
                 value=None,
                 annotation=returns,
                 docstring=self._get_docstring(node),
+                lineno=lineno,
+                endlineno=endlineno,
             )
         else:
             obj = Function(
@@ -399,6 +445,8 @@ class Inspector:
                 parameters=parameters,
                 returns=returns,
                 docstring=self._get_docstring(node),
+                lineno=lineno,
+                endlineno=endlineno,
             )
         obj.labels |= labels
         self.current.set_member(node.name, obj)
