@@ -33,7 +33,6 @@ from griffe.extensions.base import load_extensions
 from griffe.git import get_latest_tag, get_repo_root
 from griffe.loader import GriffeLoader, load, load_git
 from griffe.logger import get_logger
-from griffe.stats import _format_stats
 
 if TYPE_CHECKING:
     from griffe.extensions.base import Extensions, ExtensionType
@@ -71,8 +70,9 @@ def _load_packages(
     docstring_options: dict[str, Any] | None = None,
     resolve_aliases: bool = True,
     resolve_implicit: bool = False,
-    resolve_external: bool = False,
+    resolve_external: bool | None = None,
     allow_inspection: bool = True,
+    force_inspection: bool = False,
     store_source: bool = True,
     find_stubs_package: bool = False,
 ) -> GriffeLoader:
@@ -83,6 +83,7 @@ def _load_packages(
         docstring_parser=docstring_parser,
         docstring_options=docstring_options,
         allow_inspection=allow_inspection,
+        force_inspection=force_inspection,
         store_source=store_source,
     )
 
@@ -184,6 +185,14 @@ def get_parser() -> argparse.ArgumentParser:
             default=True,
             help="Disallow inspection of builtin/compiled/not found modules.",
         )
+        loading_options.add_argument(
+            "-x",
+            "--force-inspection",
+            dest="force_inspection",
+            action="store_true",
+            default=False,
+            help="Force inspection of everything, even when sources are found.",
+        )
         debug_options = subparser.add_argument_group(title="Debugging options")
         debug_options.add_argument(
             "-L",
@@ -256,8 +265,17 @@ def get_parser() -> argparse.ArgumentParser:
     dump_options.add_argument(
         "-U",
         "--resolve-external",
+        dest="resolve_external",
         action="store_true",
-        help="Whether to resolve aliases pointing to external/unknown modules (not loaded directly).",
+        help="Always resolve aliases pointing to external/unknown modules (not loaded directly)."
+        "Default is to resolve only from one module to its private sibling (`ast` -> `_ast`).",
+    )
+    dump_options.add_argument(
+        "--no-resolve-external",
+        dest="resolve_external",
+        action="store_false",
+        help="Never resolve aliases pointing to external/unknown modules (not loaded directly)."
+        "Default is to resolve only from one module to its private sibling (`ast` -> `_ast`).",
     )
     dump_options.add_argument(
         "-S",
@@ -315,11 +333,12 @@ def dump(
     extensions: Sequence[str | dict[str, Any] | ExtensionType | type[ExtensionType]] | None = None,
     resolve_aliases: bool = False,
     resolve_implicit: bool = False,
-    resolve_external: bool = False,
+    resolve_external: bool | None = None,
     search_paths: Sequence[str | Path] | None = None,
     find_stubs_package: bool = False,
     append_sys_path: bool = False,
     allow_inspection: bool = True,
+    force_inspection: bool = False,
     stats: bool = False,
 ) -> int:
     """Load packages data and dump it as JSON.
@@ -333,6 +352,7 @@ def dump(
         resolve_aliases: Whether to resolve aliases (indirect objects references).
         resolve_implicit: Whether to resolve every alias or only the explicitly exported ones.
         resolve_external: Whether to load additional, unspecified modules to resolve aliases.
+            Default is to resolve only from one module to its private sibling (`ast` -> `_ast`).
         extensions: The extensions to use.
         search_paths: The paths to search into.
         find_stubs_package: Whether to search for stubs-only packages.
@@ -340,6 +360,7 @@ def dump(
             If only the stubs are found, they'll be used as the package itself.
         append_sys_path: Whether to append the contents of `sys.path` to the search paths.
         allow_inspection: Whether to allow inspecting modules when visiting them is not possible.
+        force_inspection: Whether to force using dynamic analysis when loading data.
         stats: Whether to compute and log stats about loading.
 
     Returns:
@@ -355,7 +376,7 @@ def dump(
         search_paths.extend(sys.path)
 
     try:
-        loaded_extensions = load_extensions(extensions or ())
+        loaded_extensions = load_extensions(*(extensions or ()))
     except ExtensionError as error:
         logger.exception(str(error))  # noqa: TRY401
         return 1
@@ -371,6 +392,7 @@ def dump(
         resolve_implicit=resolve_implicit,
         resolve_external=resolve_external,
         allow_inspection=allow_inspection,
+        force_inspection=force_inspection,
         store_source=False,
         find_stubs_package=find_stubs_package,
     )
@@ -388,7 +410,9 @@ def dump(
     elapsed = datetime.now(tz=timezone.utc) - started
 
     if stats:
-        logger.info(_format_stats({"time_spent_serializing": elapsed.microseconds, **loader.stats()}))
+        loader_stats = loader.stats()
+        loader_stats.time_spent_serializing = elapsed.microseconds
+        logger.info(loader_stats.as_text())
 
     return 0 if len(data_packages) == len(packages) else 1
 
@@ -404,6 +428,7 @@ def check(
     append_sys_path: bool = False,
     find_stubs_package: bool = False,
     allow_inspection: bool = True,
+    force_inspection: bool = False,
     verbose: bool = False,
     color: bool | None = None,
     style: str | ExplanationStyle | None = None,
@@ -419,6 +444,7 @@ def check(
         search_paths: The paths to search into.
         append_sys_path: Whether to append the contents of `sys.path` to the search paths.
         allow_inspection: Whether to allow inspecting modules when visiting them is not possible.
+        force_inspection: Whether to force using dynamic analysis when loading data.
         verbose: Use a verbose output.
 
     Returns:
@@ -438,7 +464,7 @@ def check(
     repository = get_repo_root(against_path)
 
     try:
-        loaded_extensions = load_extensions(extensions or ())
+        loaded_extensions = load_extensions(*(extensions or ()))
     except ExtensionError as error:
         logger.exception(str(error))  # noqa: TRY401
         return 1
@@ -451,6 +477,7 @@ def check(
         extensions=loaded_extensions,
         search_paths=search_paths,
         allow_inspection=allow_inspection,
+        force_inspection=force_inspection,
     )
     if base_ref:
         new_package = load_git(
@@ -460,6 +487,7 @@ def check(
             extensions=loaded_extensions,
             search_paths=search_paths,
             allow_inspection=allow_inspection,
+            force_inspection=force_inspection,
             find_stubs_package=find_stubs_package,
         )
     else:
@@ -469,6 +497,7 @@ def check(
             extensions=loaded_extensions,
             search_paths=search_paths,
             allow_inspection=allow_inspection,
+            force_inspection=force_inspection,
             find_stubs_package=find_stubs_package,
         )
 
