@@ -176,6 +176,7 @@ class Parameter:
         annotation: str | Expr | None = None,
         kind: ParameterKind | None = None,
         default: str | Expr | None = None,
+        docstring: Docstring | None = None,
     ) -> None:
         """Initialize the parameter.
 
@@ -184,6 +185,7 @@ class Parameter:
             annotation: The parameter annotation, if any.
             kind: The parameter kind.
             default: The parameter default, if any.
+            docstring: The parameter docstring.
         """
         self.name: str = name
         """The parameter name."""
@@ -193,6 +195,12 @@ class Parameter:
         """The parameter kind."""
         self.default: str | Expr | None = default
         """The parameter default value."""
+        self.docstring: Docstring | None = docstring
+        """The parameter docstring."""
+        # The parent function is set in `Function.__init__`,
+        # when the parameters are assigned to the function.
+        self.function: Function | None = None
+        """The parent function of the parameter."""
 
     def __str__(self) -> str:
         param = f"{self.name}: {self.annotation} = {self.default}"
@@ -218,7 +226,7 @@ class Parameter:
         """Whether this parameter is required."""
         return self.default is None
 
-    def as_dict(self, **kwargs: Any) -> dict[str, Any]:  # noqa: ARG002
+    def as_dict(self, *, full: bool = False, **kwargs: Any) -> dict[str, Any]:  # noqa: ARG002
         """Return this parameter's data as a dictionary.
 
         Parameters:
@@ -227,12 +235,15 @@ class Parameter:
         Returns:
             A dictionary.
         """
-        return {
+        base: dict[str, Any] = {
             "name": self.name,
             "annotation": self.annotation,
             "kind": self.kind,
             "default": self.default,
         }
+        if self.docstring:
+            base["docstring"] = self.docstring.as_dict(full=full)
+        return base
 
 
 class Parameters:
@@ -332,16 +343,22 @@ class Object(ObjectAliasMixin):
         """
         self.name: str = name
         """The object name."""
+
         self.lineno: int | None = lineno
         """The starting line number of the object."""
+
         self.endlineno: int | None = endlineno
         """The ending line number of the object."""
+
         self.docstring: Docstring | None = docstring
         """The object docstring."""
+
         self.parent: Module | Class | None = parent
         """The parent of the object (none if top module)."""
+
         self.members: dict[str, Object | Alias] = {}
         """The object members (modules, classes, functions, attributes)."""
+
         self.labels: set[str] = set()
         """The object labels (`property`, `dataclass`, etc.)."""
 
@@ -379,9 +396,13 @@ class Object(ObjectAliasMixin):
 
         self.extra: dict[str, dict[str, Any]] = defaultdict(dict)
         """Namespaced dictionaries storing extra metadata for this object, used by extensions."""
+
         self.public: bool | None = None
         """Whether this object is public."""
 
+        self.deprecated: str | None = None
+        """Whether this object is deprecated (boolean or deprecation message)."""
+
         self._lines_collection: LinesCollection | None = lines_collection
         self._modules_collection: ModulesCollection | None = modules_collection
 
@@ -411,27 +432,14 @@ class Object(ObjectAliasMixin):
             return True
         return any(member.has_docstrings for member in self.members.values())
 
-    def member_is_exported(self, member: Object | Alias, *, explicitely: bool = True) -> bool:
-        """Whether a member of this object is "exported".
-
-        By exported, we mean that the object is included in the `__all__` attribute
-        of its parent module or class. When `__all__` is not defined,
-        we consider the member to be *implicitely* exported,
-        unless it's a module and it was not imported,
-        and unless it's not defined at runtime.
-
-        Parameters:
-            member: The member to verify.
-            explicitely: Whether to only return True when `__all__` is defined.
-
-        Returns:
-            True or False.
-        """
-        if not member.runtime:
-            return False
-        if self.exports is None:
-            return not explicitely and (member.is_alias or not member.is_module or member.name in self.imports)
-        return member.name in self.exports
+    def member_is_exported(self, member: Object | Alias, *, explicitely: bool = True) -> bool:  # noqa: ARG002
+        """Deprecated. Use [`member.is_exported`][griffe.dataclasses.Object.is_exported] instead."""
+        warnings.warn(
+            "Method `member_is_exported` is deprecated. Use `member.is_exported` instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return member.is_exported
 
     def is_kind(self, kind: str | Kind | set[str | Kind]) -> bool:
         """Tell if this object is of the given kind.
@@ -519,16 +527,28 @@ class Object(ObjectAliasMixin):
         """Whether this object is a namespace subpackage."""
         return False
 
-    def has_labels(self, labels: set[str]) -> bool:
+    def has_labels(self, *labels: str | set[str]) -> bool:
         """Tell if this object has all the given labels.
 
         Parameters:
-            labels: A set of labels.
+            *labels: Labels that must be present.
 
         Returns:
             True or False.
         """
-        return all(label in self.labels for label in labels)
+        # TODO: Remove at some point.
+        all_labels = set()
+        for label in labels:
+            if isinstance(label, str):
+                all_labels.add(label)
+            else:
+                warnings.warn(
+                    "Passing a set of labels to `has_labels` is deprecated. Pass multiple strings instead.",
+                    DeprecationWarning,
+                    stacklevel=2,
+                )
+                all_labels.update(label)
+        return all_labels.issubset(self.labels)
 
     def filter_members(self, *predicates: Callable[[Object | Alias], bool]) -> dict[str, Object | Alias]:
         """Filter and return members based on predicates.
@@ -687,13 +707,14 @@ class Object(ObjectAliasMixin):
             return []
         if isinstance(filepath, list):
             return []
-
         try:
             lines = self.lines_collection[filepath]
         except KeyError:
             return []
-        if self.lineno is None or self.endlineno is None:
+        if self.is_module:
             return lines
+        if self.lineno is None or self.endlineno is None:
+            return []
         return lines[self.lineno - 1 : self.endlineno]
 
     @property
@@ -818,21 +839,31 @@ class Alias(ObjectAliasMixin):
         """
         self.name: str = name
         """The alias name."""
+
         self.alias_lineno: int | None = lineno
         """The starting line number of the alias."""
+
         self.alias_endlineno: int | None = endlineno
         """The ending line number of the alias."""
+
         self.runtime: bool = runtime
         """Whether this alias is available at runtime."""
+
         self.inherited: bool = inherited
         """Whether this alias represents an inherited member."""
+
         self.public: bool | None = None
         """Whether this alias is public."""
+
+        self.deprecated: str | bool | None = None
+        """Whether this alias is deprecated (boolean or deprecation message)."""
+
         self._parent: Module | Class | Alias | None = parent
         self._passed_through: bool = False
 
         self.target_path: str
         """The path of this alias' target."""
+
         if isinstance(target, str):
             self._target: Object | Alias | None = None
             self.target_path = target
@@ -1016,23 +1047,14 @@ class Alias(ObjectAliasMixin):
         """The aliases pointing to this object."""
         return self.final_target.aliases
 
-    def member_is_exported(self, member: Object | Alias, *, explicitely: bool = True) -> bool:
-        """Whether a member of this object is "exported".
-
-        By exported, we mean that the object is included in the `__all__` attribute
-        of its parent module or class. When `__all__` is not defined,
-        we consider the member to be *implicitely* exported,
-        unless it's a module and it was not imported,
-        and unless it's not defined at runtime.
-
-        Parameters:
-            member: The member to verify.
-            explicitely: Whether to only return True when `__all__` is defined.
-
-        Returns:
-            True or False.
-        """
-        return self.final_target.member_is_exported(member, explicitely=explicitely)
+    def member_is_exported(self, member: Object | Alias, *, explicitely: bool = True) -> bool:  # noqa: ARG002
+        """Deprecated. Use [`member.is_exported`][griffe.dataclasses.Alias.is_exported] instead."""
+        warnings.warn(
+            "Method `member_is_exported` is deprecated. Use `member.is_exported` instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return member.is_exported
 
     def is_kind(self, kind: str | Kind | set[str | Kind]) -> bool:
         """Tell if this object is of the given kind.
@@ -1068,16 +1090,16 @@ class Alias(ObjectAliasMixin):
         """Whether this object is an attribute."""
         return self.final_target.is_attribute
 
-    def has_labels(self, labels: set[str]) -> bool:
+    def has_labels(self, *labels: str | set[str]) -> bool:
         """Tell if this object has all the given labels.
 
         Parameters:
-            labels: A set of labels.
+            *labels: Labels that must be present.
 
         Returns:
             True or False.
         """
-        return self.final_target.has_labels(labels)
+        return self.final_target.has_labels(*labels)
 
     def filter_members(self, *predicates: Callable[[Object | Alias], bool]) -> dict[str, Object | Alias]:
         """Filter and return members based on predicates.
@@ -1659,6 +1681,9 @@ class Function(Object):
         self.overloads: list[Function] | None = None
         """The overloaded signatures of this function."""
 
+        for parameter in self.parameters:
+            parameter.function = self
+
     @property
     def annotation(self) -> str | Expr | None:
         """The type annotation of the returned value."""
