@@ -468,14 +468,17 @@ def _handle_editable_module(path: Path) -> list[_SP]:
     if _match_pattern(path.name, _editable_setuptools_patterns):
         # Support for how 'setuptools' writes these files:
         # example line: `MAPPING = {'griffe': '/media/data/dev/griffe/src/griffe', 'briffe': '/media/data/dev/griffe/src/briffe'}`.
+        # with annotation: `MAPPING: dict[str, str] = {...}`.
         parsed_module = ast.parse(path.read_text())
         for node in parsed_module.body:
-            if (
-                isinstance(node, ast.Assign)
-                and isinstance(node.targets[0], ast.Name)
-                and node.targets[0].id == "MAPPING"
-            ) and isinstance(node.value, ast.Dict):
-                return [_SP(Path(cst.value).parent) for cst in node.value.values if isinstance(cst, ast.Constant)]
+            if isinstance(node, ast.Assign):
+                target = node.targets[0]
+            elif isinstance(node, ast.AnnAssign):
+                target = node.target
+            else:
+                continue
+            if isinstance(target, ast.Name) and target.id == "MAPPING" and isinstance(node.value, ast.Dict):  # type: ignore[attr-defined]
+                return [_SP(Path(cst.value).parent) for cst in node.value.values if isinstance(cst, ast.Constant)]  # type: ignore[attr-defined]
     if _match_pattern(path.name, _editable_meson_python_patterns):
         # Support for how 'meson-python' writes these files:
         # example line: `install({'package', 'module1'}, '/media/data/dev/griffe/build/cp311', ["path"], False)`.
