@@ -29,9 +29,10 @@ from griffe.expressions import ExprName
 from griffe.extensions.base import Extensions, load_extensions
 from griffe.finder import ModuleFinder, NamespacePackage, Package
 from griffe.git import tmp_worktree
+from griffe.importer import dynamic_import
 from griffe.logger import get_logger
 from griffe.merger import merge_stubs
-from griffe.stats import stats
+from griffe.stats import Stats
 
 if TYPE_CHECKING:
     from griffe.enumerations import Parser
@@ -55,6 +56,7 @@ class GriffeLoader:
         lines_collection: LinesCollection | None = None,
         modules_collection: ModulesCollection | None = None,
         allow_inspection: bool = True,
+        force_inspection: bool = False,
         store_source: bool = True,
     ) -> None:
         """Initialize the loader.
@@ -81,6 +83,8 @@ class GriffeLoader:
         """Collection of modules."""
         self.allow_inspection: bool = allow_inspection
         """Whether to allow inspecting (importing) modules for which we can't find sources."""
+        self.force_inspection: bool = force_inspection
+        """Whether to force inspecting (importing) modules, even when sources were found."""
         self.store_source: bool = store_source
         """Whether to store source code in the lines collection."""
         self.finder: ModuleFinder = ModuleFinder(search_paths)
@@ -108,7 +112,7 @@ class GriffeLoader:
             DeprecationWarning,
             stacklevel=2,
         )
-        return self.load(
+        return self.load(  # type: ignore[return-value]
             module,
             submodules=submodules,
             try_relative_path=try_relative_path,
@@ -125,7 +129,7 @@ class GriffeLoader:
         find_stubs_package: bool = False,
         # TODO: Remove at some point.
         module: str | Path | None = None,
-    ) -> Object:
+    ) -> Object | Alias:
         """Load an object as a Griffe object, given its Python or file path.
 
         Note that this will load the whole object's package,
@@ -159,6 +163,7 @@ class GriffeLoader:
         # TODO: Remove at some point.
         if objspec is None and module is None:
             raise TypeError("load() missing 1 required positional argument: 'objspec'")
+
         if objspec is None:
             objspec = module
             warnings.warn(
@@ -166,18 +171,14 @@ class GriffeLoader:
                 DeprecationWarning,
                 stacklevel=2,
             )
+
         obj_path: str
-        if objspec in _builtin_modules:
-            logger.debug(f"{objspec} is a builtin module")
-            if self.allow_inspection:
-                logger.debug(f"Inspecting {objspec}")
-                obj_path = objspec  # type: ignore[assignment]
-                top_module = self._inspect_module(objspec)  # type: ignore[arg-type]
-                self.modules_collection.set_member(top_module.path, top_module)
-                obj = self.modules_collection.get_member(obj_path)
-                self.extensions.call("on_package_loaded", pkg=obj)
-                return obj
-            raise LoadingError("Cannot load builtin module without inspection")
+        package = None
+        top_module = None
+
+        # We always start by searching paths on the disk,
+        # even if inspection is forced.
+        logger.debug(f"Searching path(s) for {objspec}")
         try:
             obj_path, package = self.finder.find_spec(
                 objspec,  # type: ignore[arg-type]
@@ -185,30 +186,58 @@ class GriffeLoader:
                 find_stubs_package=find_stubs_package,
             )
         except ModuleNotFoundError:
-            logger.debug(f"Could not find {objspec}")
-            if self.allow_inspection:
-                logger.debug(f"Trying inspection on {objspec}")
-                obj_path = objspec  # type: ignore[assignment]
-                top_module = self._inspect_module(objspec)  # type: ignore[arg-type]
-                self.modules_collection.set_member(top_module.path, top_module)
-            else:
+            # If we couldn't find paths on disk and inspection is disabled,
+            # re-raise ModuleNotFoundError.
+            logger.debug(f"Could not find path for {objspec} on disk")
+            if not (self.allow_inspection or self.force_inspection):
                 raise
-        else:
-            logger.debug(f"Found {objspec}: loading")
+
+            # Otherwise we try to dynamically import the top-level module.
+            obj_path = str(objspec)
+            top_module_name = obj_path.split(".", 1)[0]
+            logger.debug(f"Trying to dynamically import {top_module_name}")
+            top_module_object = dynamic_import(top_module_name, self.finder.search_paths)
+
             try:
-                top_module = self._load_package(package, submodules=submodules)
-            except LoadingError as error:
-                logger.exception(str(error))  # noqa: TRY401
-                raise
+                top_module_path = top_module_object.__path__
+                if not top_module_path:
+                    raise ValueError(f"Module {top_module_name} has no paths set")  # noqa: TRY301
+            except (AttributeError, ValueError):
+                # If the top-level module has no `__path__`, we inspect it as-is,
+                # and do not try to recurse into submodules (there shouldn't be any in builtin/compiled modules).
+                logger.debug(f"Module {top_module_name} has no paths set (built-in module?). Inspecting it as-is.")
+                top_module = self._inspect_module(top_module_name)
+                self.modules_collection.set_member(top_module.path, top_module)
+                obj = self.modules_collection.get_member(obj_path)
+                self.extensions.call("on_package_loaded", pkg=obj)
+                return obj
+
+            # We found paths, and use them to build our intermediate Package or NamespacePackage struct.
+            logger.debug(f"Module {top_module_name} has paths set: {top_module_path}")
+            top_module_path = [Path(path) for path in top_module_path]
+            if len(top_module_path) > 1:
+                package = NamespacePackage(top_module_name, top_module_path)
+            else:
+                package = Package(top_module_name, top_module_path[0])
+
+        # We have an intermediate package, and an object path: we're ready to load.
+        logger.debug(f"Found {objspec}: loading")
+        try:
+            top_module = self._load_package(package, submodules=submodules)
+        except LoadingError as error:
+            logger.exception(str(error))  # noqa: TRY401
+            raise
+
+        # Package is loaded, we now retrieve the initially requested object and return it.
         obj = self.modules_collection.get_member(obj_path)
-        self.extensions.call("on_package_loaded", pkg=obj)
+        self.extensions.call("on_package_loaded", pkg=top_module)
         return obj
 
     def resolve_aliases(
         self,
         *,
         implicit: bool = False,
-        external: bool = False,
+        external: bool | None = None,
         max_iterations: int | None = None,
     ) -> tuple[set[str], int]:
         """Resolve aliases.
@@ -294,7 +323,7 @@ class GriffeLoader:
         self,
         obj: Object,
         *,
-        external: bool = False,
+        external: bool | None = None,
         seen: set | None = None,
     ) -> None:
         """Expand wildcards: try to recursively expand all found wildcards.
@@ -319,11 +348,11 @@ class GriffeLoader:
 
                 # Try loading the (unknown) package containing the wildcard importe module (if allowed to).
                 if not_loaded:
-                    if not external:
+                    if external is False or (external is None and package != f"_{obj.package.name}"):
                         continue
                     try:
                         self.load(package, try_relative_path=False)
-                    except ImportError as error:
+                    except (ImportError, LoadingError) as error:
                         logger.debug(f"Could not expand wildcard import {member.name} in {obj.path}: {error}")
                         continue
 
@@ -407,7 +436,7 @@ class GriffeLoader:
         obj: Object | Alias,
         *,
         implicit: bool = False,
-        external: bool = False,
+        external: bool | None = None,
         seen: set[str] | None = None,
         load_failures: set[str] | None = None,
     ) -> tuple[set[str], set[str]]:
@@ -435,7 +464,7 @@ class GriffeLoader:
             if member.is_alias:
                 if member.wildcard or member.resolved:  # type: ignore[union-attr]
                     continue
-                if not implicit and not member.is_explicitely_exported:
+                if not implicit and not member.is_exported:
                     continue
 
                 # Try resolving the alias. If it fails, check if it is because it comes
@@ -448,7 +477,7 @@ class GriffeLoader:
                     unresolved.add(member.path)
                     package = target.split(".", 1)[0]
                     load_module = (
-                        external
+                        (external is True or (external is None and package == f"_{obj.package.name}"))
                         and package not in load_failures
                         and obj.package.path != package
                         and package not in self.modules_collection
@@ -457,7 +486,7 @@ class GriffeLoader:
                         logger.debug(f"Failed to resolve alias {member.path} -> {target}")
                         try:
                             self.load(package, try_relative_path=False)
-                        except ImportError as error:
+                        except (ImportError, LoadingError) as error:
                             logger.debug(f"Could not follow alias {member.path}: {error}")
                             load_failures.add(package)
                 except CyclicAliasError as error:
@@ -480,13 +509,16 @@ class GriffeLoader:
 
         return resolved, unresolved
 
-    def stats(self) -> dict:
+    def stats(self) -> Stats:
         """Compute some statistics.
 
         Returns:
             Some statistics.
         """
-        return {**stats(self), **self._time_stats}
+        stats = Stats(self)
+        stats.time_spent_visiting = self._time_stats["time_spent_visiting"]
+        stats.time_spent_inspecting = self._time_stats["time_spent_inspecting"]
+        return stats
 
     def _load_package(self, package: Package | NamespacePackage, *, submodules: bool = True) -> Module:
         top_module = self._load_module(package.name, package.path, submodules=submodules)
@@ -534,9 +566,10 @@ class GriffeLoader:
         logger.debug(f"Loading path {module_path}")
         if isinstance(module_path, list):
             module = self._create_module(module_name, module_path)
+        elif self.force_inspection:
+            module = self._inspect_module(module_name, module_path, parent)
         elif module_path.suffix in {".py", ".pyi"}:
-            code = module_path.read_text(encoding="utf8")
-            module = self._visit_module(code, module_name, module_path, parent)
+            module = self._visit_module(module_name, module_path, parent)
         elif self.allow_inspection:
             module = self._inspect_module(module_name, module_path, parent)
         else:
@@ -559,7 +592,7 @@ class GriffeLoader:
         except UnimportableModuleError as error:
             # NOTE: Why don't we load submodules when there's no init module in their folder?
             # Usually when a folder with Python files does not have an __init__.py module,
-            # it's because the Python files are scripts, that should never be imported.
+            # it's because the Python files are scripts that should never be imported.
             # Django has manage.py somewhere for example, in a folder without init module.
             # This script isn't part of the Python API, as it's meant to be called on the CLI exclusively
             # (at least it was the case a few years ago when I was still using Django).
@@ -590,11 +623,13 @@ class GriffeLoader:
             logger.debug(str(error))
         else:
             if submodule_name in parent_module.members:
-                logger.debug(
-                    f"Submodule '{submodule.path}' is shadowing the member at the same path. "
-                    "We recommend renaming the member or the submodule (for example prefixing it with `_`), "
-                    "see https://mkdocstrings.github.io/griffe/best_practices/#avoid-member-submodule-name-shadowing.",
-                )
+                member = parent_module.members[submodule_name]
+                if member.is_alias or not member.is_module:
+                    logger.debug(
+                        f"Submodule '{submodule.path}' is shadowing the member at the same path. "
+                        "We recommend renaming the member or the submodule (for example prefixing it with `_`), "
+                        "see https://mkdocstrings.github.io/griffe/best_practices/#avoid-member-submodule-name-shadowing.",
+                    )
             parent_module.set_member(submodule_name, submodule)
 
     def _create_module(self, module_name: str, module_path: Path | list[Path]) -> Module:
@@ -605,7 +640,8 @@ class GriffeLoader:
             modules_collection=self.modules_collection,
         )
 
-    def _visit_module(self, code: str, module_name: str, module_path: Path, parent: Module | None = None) -> Module:
+    def _visit_module(self, module_name: str, module_path: Path, parent: Module | None = None) -> Module:
+        code = module_path.read_text(encoding="utf8")
         if self.store_source:
             self.lines_collection[module_path] = code.splitlines(keepends=False)
         start = datetime.now(tz=timezone.utc)
@@ -628,6 +664,8 @@ class GriffeLoader:
         for prefix in self.ignored_modules:
             if module_name.startswith(prefix):
                 raise ImportError(f"Ignored module '{module_name}'")
+        if self.store_source and filepath and filepath.suffix in {".py", ".pyi"}:
+            self.lines_collection[filepath] = filepath.read_text(encoding="utf8").splitlines(keepends=False)
         start = datetime.now(tz=timezone.utc)
         try:
             module = inspect(
@@ -639,6 +677,7 @@ class GriffeLoader:
                 docstring_parser=self.docstring_parser,
                 docstring_options=self.docstring_options,
                 lines_collection=self.lines_collection,
+                modules_collection=self.modules_collection,
             )
         except SystemExit as error:
             raise ImportError(f"Importing '{module_name}' raised a system exit") from error
@@ -678,11 +717,10 @@ class GriffeLoader:
 
     def _expand_wildcard(self, wildcard_obj: Alias) -> list[tuple[Object | Alias, int | None, int | None]]:
         module = self.modules_collection.get_member(wildcard_obj.wildcard)  # type: ignore[arg-type]  # we know it's a wildcard
-        explicitely = "__all__" in module.members
         return [
             (imported_member, wildcard_obj.alias_lineno, wildcard_obj.alias_endlineno)
             for imported_member in module.members.values()
-            if imported_member.is_exported(explicitely=explicitely)
+            if imported_member.is_wildcard_exposed
         ]
 
 
@@ -699,11 +737,15 @@ def load(
     lines_collection: LinesCollection | None = None,
     modules_collection: ModulesCollection | None = None,
     allow_inspection: bool = True,
+    force_inspection: bool = False,
     store_source: bool = True,
     find_stubs_package: bool = False,
     # TODO: Remove at some point.
     module: str | Path | None = None,
-) -> Object:
+    resolve_aliases: bool = False,
+    resolve_external: bool | None = None,
+    resolve_implicit: bool = False,
+) -> Object | Alias:
     """Load and return a module.
 
     Example:
@@ -736,16 +778,22 @@ def load(
         lines_collection: A collection of source code lines.
         modules_collection: A collection of modules.
         allow_inspection: Whether to allow inspecting modules when visiting them is not possible.
+        force_inspection: Whether to force using dynamic analysis when loading data.
         store_source: Whether to store code source in the lines collection.
         find_stubs_package: Whether to search for stubs-only package.
             If both the package and its stubs are found, they'll be merged together.
             If only the stubs are found, they'll be used as the package itself.
         module: Deprecated. Use `objspec` positional-only parameter instead.
+        resolve_aliases: Whether to resolve aliases.
+        resolve_external: Whether to try to load unspecified modules to resolve aliases.
+            Default value (`None`) means to load external modules only if they are the private sibling
+            or the origin module (for example when `ast` imports from `_ast`).
+        resolve_implicit: When false, only try to resolve an alias if it is explicitely exported.
 
     Returns:
         A Griffe object.
     """
-    return GriffeLoader(
+    loader = GriffeLoader(
         extensions=extensions,
         search_paths=search_paths,
         docstring_parser=docstring_parser,
@@ -753,8 +801,10 @@ def load(
         lines_collection=lines_collection,
         modules_collection=modules_collection,
         allow_inspection=allow_inspection,
+        force_inspection=force_inspection,
         store_source=store_source,
-    ).load(
+    )
+    result = loader.load(
         objspec,
         submodules=submodules,
         try_relative_path=try_relative_path,
@@ -762,6 +812,9 @@ def load(
         # TODO: Remove at some point.
         module=module,
     )
+    if resolve_aliases:
+        loader.resolve_aliases(implicit=resolve_implicit, external=resolve_external)
+    return result
 
 
 def load_git(
@@ -778,10 +831,14 @@ def load_git(
     lines_collection: LinesCollection | None = None,
     modules_collection: ModulesCollection | None = None,
     allow_inspection: bool = True,
+    force_inspection: bool = False,
     find_stubs_package: bool = False,
     # TODO: Remove at some point.
     module: str | Path | None = None,
-) -> Object:
+    resolve_aliases: bool = False,
+    resolve_external: bool | None = None,
+    resolve_implicit: bool = False,
+) -> Object | Alias:
     """Load and return a module from a specific Git reference.
 
     This function will create a temporary
@@ -810,10 +867,16 @@ def load_git(
         lines_collection: A collection of source code lines.
         modules_collection: A collection of modules.
         allow_inspection: Whether to allow inspecting modules when visiting them is not possible.
+        force_inspection: Whether to force using dynamic analysis when loading data.
         find_stubs_package: Whether to search for stubs-only package.
             If both the package and its stubs are found, they'll be merged together.
             If only the stubs are found, they'll be used as the package itself.
         module: Deprecated. Use `objspec` positional-only parameter instead.
+        resolve_aliases: Whether to resolve aliases.
+        resolve_external: Whether to try to load unspecified modules to resolve aliases.
+            Default value (`None`) means to load external modules only if they are the private sibling
+            or the origin module (for example when `ast` imports from `_ast`).
+        resolve_implicit: When false, only try to resolve an alias if it is explicitely exported.
 
     Returns:
         A Griffe object.
@@ -836,9 +899,13 @@ def load_git(
             lines_collection=lines_collection,
             modules_collection=modules_collection,
             allow_inspection=allow_inspection,
+            force_inspection=force_inspection,
             find_stubs_package=find_stubs_package,
             # TODO: Remove at some point.
             module=module,
+            resolve_aliases=resolve_aliases,
+            resolve_external=resolve_external,
+            resolve_implicit=resolve_implicit,
         )
 
 
