@@ -8,27 +8,26 @@ from textwrap import dedent
 import pytest
 
 import griffe
-from griffe.dataclasses import Docstring, Module
+from griffe.dataclasses import Attribute, Docstring, Module
 from griffe.loader import GriffeLoader
-from griffe.tests import module_vtree, temporary_pypackage, temporary_visited_package
+from griffe.tests import module_vtree, temporary_inspected_module, temporary_pypackage, temporary_visited_package
 
 
 def test_submodule_exports() -> None:
     """Check that a module is exported depending on whether it was also imported."""
     root = Module("root")
     sub = Module("sub")
+    private = Attribute("_private")
     root["sub"] = sub
+    root["_private"] = private
 
-    assert not root.member_is_exported(sub, explicitely=True)
-    assert not root.member_is_exported(sub, explicitely=False)
-
+    assert not sub.is_wildcard_exposed
     root.imports["sub"] = "root.sub"
-    assert not root.member_is_exported(sub, explicitely=True)
-    assert root.member_is_exported(sub, explicitely=False)
+    assert sub.is_wildcard_exposed
 
-    root.exports = {"sub"}
-    assert root.member_is_exported(sub, explicitely=True)
-    assert root.member_is_exported(sub, explicitely=False)
+    assert not private.is_wildcard_exposed
+    root.exports = {"_private"}
+    assert private.is_wildcard_exposed
 
 
 def test_has_docstrings() -> None:
@@ -315,3 +314,110 @@ def test_parameters_annotated_as_initvar() -> None:
         point_b = module["PointB"]
         assert ["self", "r"] == [p.name for p in point_b.parameters]
         assert ["x", "y", "z", "__init__"] == list(point_b.members)
+
+
+def test_visited_module_source() -> None:
+    """Check the source property of a module."""
+    code = "print('hello')\nprint('world')"
+    with temporary_visited_package("package", {"__init__.py": code}) as module:
+        assert module.source == code
+
+
+def test_visited_class_source() -> None:
+    """Check the source property of a class."""
+    code = """
+    class A:
+        def __init__(self, x: int):
+            self.x = x
+    """
+    with temporary_visited_package("package", {"__init__.py": code}) as module:
+        assert module["A"].source == dedent(code).strip()
+
+
+def test_visited_object_source_with_missing_line_number() -> None:
+    """Check the source property of an object with missing line number."""
+    code = """
+    class A:
+        def __init__(self, x: int):
+            self.x = x
+    """
+    with temporary_visited_package("package", {"__init__.py": code}) as module:
+        module["A"].endlineno = None
+        assert not module["A"].source
+        module["A"].endlineno = 3
+        module["A"].lineno = None
+        assert not module["A"].source
+
+
+def test_inspected_module_source() -> None:
+    """Check the source property of a module."""
+    code = "print('hello')\nprint('world')"
+    with temporary_inspected_module(code) as module:
+        assert module.source == code
+
+
+def test_inspected_class_source() -> None:
+    """Check the source property of a class."""
+    code = """
+    class A:
+        def __init__(self, x: int):
+            self.x = x
+    """
+    with temporary_inspected_module(code) as module:
+        assert module["A"].source == dedent(code).strip()
+
+
+def test_inspected_object_source_with_missing_line_number() -> None:
+    """Check the source property of an object with missing line number."""
+    code = """
+    class A:
+        def __init__(self, x: int):
+            self.x = x
+    """
+    with temporary_inspected_module(code) as module:
+        module["A"].endlineno = None
+        assert not module["A"].source
+        module["A"].endlineno = 3
+        module["A"].lineno = None
+        assert not module["A"].source
+
+
+def test_dataclass_parameter_docstrings() -> None:
+    """Class parameters should have a docstring attribute."""
+    code = """
+    from dataclasses import dataclass, InitVar
+
+    @dataclass
+    class Base:
+        a: int
+        "Parameter a"
+        b: InitVar[int] = 3
+        "Parameter b"
+
+    @dataclass
+    class Derived(Base):
+        c: float
+        d: InitVar[float]
+        "Parameter d"
+    """
+
+    with temporary_visited_package("package", {"__init__.py": code}) as module:
+        base = module["Base"]
+        param_self = base.parameters[0]
+        param_a = base.parameters[1]
+        param_b = base.parameters[2]
+        assert param_self.docstring is None
+        assert param_a.docstring.value == "Parameter a"
+        assert param_b.docstring.value == "Parameter b"
+
+        derived = module["Derived"]
+        param_self = derived.parameters[0]
+        param_a = derived.parameters[1]
+        param_b = derived.parameters[2]
+        param_c = derived.parameters[3]
+        param_d = derived.parameters[4]
+        assert param_self.docstring is None
+        assert param_a.docstring.value == "Parameter a"
+        assert param_b.docstring.value == "Parameter b"
+        assert param_c.docstring is None
+        assert param_d.docstring.value == "Parameter d"
