@@ -11,10 +11,13 @@ import pytest
 from griffe.expressions import ExprName
 from griffe.loader import GriffeLoader
 from griffe.tests import temporary_pyfile, temporary_pypackage, temporary_visited_package
+from tests.helpers import clear_sys_modules
 
 if TYPE_CHECKING:
     from pathlib import Path
 
+    from griffe.dataclasses import Alias
+
 
 def test_has_docstrings_does_not_try_to_resolve_alias() -> None:
     """Assert that checkins presence of docstrings does not trigger alias resolution."""
@@ -47,7 +50,7 @@ def test_recursive_wildcard_expansion() -> None:
         assert "CONST_X" not in package.members
         assert "CONST_Y" not in package.members
 
-        loader.expand_wildcards(package)
+        loader.expand_wildcards(package)  # type: ignore[arg-type]
 
         assert "CONST_X" in package["mod_a"].members
         assert "CONST_Y" in package["mod_a"].members
@@ -421,3 +424,65 @@ def test_submodule_shadowing_member(init: str, caplog: pytest.LogCaptureFixture)
         init=True,
     ):
         assert "shadowing" in caplog.text
+
+
+@pytest.mark.parametrize("wildcard", [True, False])
+@pytest.mark.parametrize(("external", "foo_is_resolved"), [(None, True), (True, True), (False, False)])
+def test_side_loading_sibling_private_module(wildcard: bool, external: bool | None, foo_is_resolved: bool) -> None:
+    """Automatically load `_a` when `a` (wildcard) imports from it.
+
+    Parameters:
+        wildcard: Whether the import is a wildcard import.
+        external: Value for the `external` parameter when resolving aliases.
+        foo_is_resolved: Whether the `foo` alias should be resolved.
+    """
+    with temporary_pypackage("_a", {"__init__.py": "def foo():\n    '''Docstring.'''"}) as pkg_a:  # noqa: SIM117
+        with temporary_pypackage("a", {"__init__.py": f"from _a import {'*' if wildcard else 'foo'}"}) as pkg_a_private:
+            loader = GriffeLoader(search_paths=[pkg_a.tmpdir, pkg_a_private.tmpdir])
+            package = loader.load("a")
+            loader.resolve_aliases(external=external, implicit=True)
+            if foo_is_resolved:
+                assert "foo" in package.members
+                assert package["foo"].is_alias
+                assert package["foo"].resolved
+                assert package["foo"].docstring.value == "Docstring."
+            elif wildcard:
+                assert "foo" not in package.members
+            else:
+                assert "foo" in package.members
+                assert package["foo"].is_alias
+                assert not package["foo"].resolved
+
+
+def test_forcing_inspection() -> None:
+    """Load a package with forced dynamic analysis."""
+    with temporary_pypackage("pkg", {"__init__.py": "a = 0", "mod.py": "b = 1"}) as pkg:
+        static_loader = GriffeLoader(force_inspection=False, search_paths=[pkg.tmpdir])
+        dynamic_loader = GriffeLoader(force_inspection=True, search_paths=[pkg.tmpdir])
+        static_package = static_loader.load("pkg")
+        dynamic_package = dynamic_loader.load("pkg")
+        for name in static_package.members:
+            assert name in dynamic_package.members
+        for name in static_package["mod"].members:
+            assert name in dynamic_package["mod"].members
+    clear_sys_modules("pkg")
+
+
+def test_relying_on_modules_path_attribute(monkeypatch: pytest.MonkeyPatch) -> None:
+    """Load a package that relies on the `__path__` attribute of a module."""
+
+    def raise_module_not_found_error(*args, **kwargs) -> None:  # noqa: ARG001,ANN002,ANN003
+        raise ModuleNotFoundError
+
+    loader = GriffeLoader()
+    monkeypatch.setattr(loader.finder, "find_spec", raise_module_not_found_error)
+    assert loader.load("griffe")
+
+
+def test_not_calling_package_loaded_hook_on_something_else_than_package() -> None:
+    """Always call the `on_package_loaded` hook on a package, not any other object."""
+    with temporary_pypackage("pkg", {"__init__.py": "from typing import List as L"}) as pkg:
+        loader = GriffeLoader(search_paths=[pkg.tmpdir])
+        alias: Alias = loader.load("pkg.L")  # type: ignore[assignment]
+        assert alias.is_alias
+        assert not alias.resolved
